searchNodes=[{"ref":"EctoResource.html","title":"EctoResource","type":"module","doc":"This module provides a DSL to easily generate the basic functions for a schema. This allows the context to focus on interesting, atypical implementations rather than the redundent, drifting CRUD functions."},{"ref":"EctoResource.html#__using__/1","title":"EctoResource.__using__/1","type":"macro","doc":"Macro to import EctoResource.using_repo/2 Examples use EctoResource"},{"ref":"EctoResource.html#resource/2","title":"EctoResource.resource/2","type":"macro","doc":"Macro to define CRUD methods for the given Ecto.Repo in the using module. Examples using(Repo) do resource(Schema) end using(Repo) do resource(Schema, only: [:get]) end using(Repo) do resource(Schema, except: [:delete]) end using(Repo) do resource(Schema, :read) end using(Repo) do resource(Schema, :write) end using(Repo) do resource(Schema, :delete) end"},{"ref":"EctoResource.html#using_repo/2","title":"EctoResource.using_repo/2","type":"macro","doc":"Macro to define schema access within a given Ecto.Repo Examples using_repo(Repo) do resource(Schema) end"},{"ref":"Mix.Tasks.EctoResource.Resources.html","title":"Mix.Tasks.EctoResource.Resources","type":"task","doc":"Task to list the resources defined by EctoResource within a context module. Examples $ mix ecto_resource.resources MyApp.MyContext Within the context Account, the following resource functions have been generated: User using the repo Repo: - Accounts.all_users/1 - Accounts.change_user/1 - Accounts.create_user/1 - Accounts.create_user!/1 - Accounts.delete_user/1 - Accounts.delete_user!/1 - Accounts.get_user/2 - Accounts.get_user!/2 - Accounts.update_user/2 - Accounts.update_user!/2"},{"ref":"Mix.Tasks.EctoResource.Resources.html#run/1","title":"Mix.Tasks.EctoResource.Resources.run/1","type":"function","doc":"Run the task to list the resources. Examples iex&gt;"},{"ref":"readme.html","title":"EctoResource","type":"extras","doc":"EctoResource Eliminate boilerplate involved in defining basic CRUD functions in a Phoenix context or Elixir module. Turn this: defmodule MyApp.Accounts do @moduledoc &quot;&quot;&quot; The Accounts context. &quot;&quot;&quot; import Ecto.Query, warn: false alias MyApp.Repo alias MyApp.Accounts.User @doc &quot;&quot;&quot; Returns the list of users. ## Examples iex&gt; all_users() [%User{}, ...] &quot;&quot;&quot; def all_users do Repo.all(User) end @doc &quot;&quot;&quot; Gets a single user. ## Examples iex&gt; get_user(123) {:ok, %User{}} iex&gt; get_user(456) {:error, %Ecto.Changeset{}} &quot;&quot;&quot; def get_user(id), do: Repo.get(User, id) @doc &quot;&quot;&quot; Gets a single user. Raises [`Ecto.NoResultsError`](https://hexdocs.pm/ecto/3.1.7/Ecto.NoResultsError.html) if the User does not exist. ## Examples iex&gt; get_user!(123) %User{} iex&gt; get_user!(456) ** (Ecto.NoResultsError) &quot;&quot;&quot; def get_user!(id), do: Repo.get!(User, id) @doc &quot;&quot;&quot; Creates a user. ## Examples iex&gt; create_user(%{field: value}) {:ok, %User{}} iex&gt; create_user(%{field: bad_value}) {:error, %Ecto.Changeset{}} &quot;&quot;&quot; def create_user(attrs \\\\ %{}) do %User{} |&gt; User.changeset(attrs) |&gt; Repo.insert() end @doc &quot;&quot;&quot; Creates a user. Raises [`Postgrex.Error`](https://hexdocs.pm/postgrex/0.15.0/Postgrex.Error.html) if the insert fails. ## Examples iex&gt; create_user!(%{field: value}) {:ok, %User{}} iex&gt; create_user!(%{field: bad_value}) ** (Postgrex.Error) &quot;&quot;&quot; def create_user!(attrs \\\\ %{}) do %User{} |&gt; User.changeset(attrs) |&gt; Repo.insert!() end @doc &quot;&quot;&quot; Updates a user. ## Examples iex&gt; update_user(user, %{field: new_value}) {:ok, %User{}} iex&gt; update_user(user, %{field: bad_value}) {:error, %Ecto.Changeset{}} &quot;&quot;&quot; def update_user(%User{} = user, attrs) do user |&gt; User.changeset(attrs) |&gt; Repo.update() end @doc &quot;&quot;&quot; Updates a user. Raises [`Postgrex.Error`](https://hexdocs.pm/postgrex/0.15.0/Postgrex.Error.html) if the update fails. ## Examples iex&gt; update_user!(user, %{field: new_value}) {:ok, %User{}} iex&gt; update_user!(user, %{field: bad_value}) ** (Postgrex.Error) &quot;&quot;&quot; def update_user!(%User{} = user, attrs) do user |&gt; User.changeset(attrs) |&gt; Repo.update!() end @doc &quot;&quot;&quot; Deletes a User. ## Examples iex&gt; delete_user(user) {:ok, %User{}} iex&gt; delete_user(user) {:error, %Ecto.Changeset{}} &quot;&quot;&quot; def delete_user(%User{} = user) do Repo.delete(user) end @doc &quot;&quot;&quot; Deletes a User. Raises [`Postgrex.Error`](https://hexdocs.pm/postgrex/0.15.0/Postgrex.Error.html) if the delete fails. ## Examples iex&gt; delete_user!(user) {:ok, %User{}} iex&gt; delete_user!(user) ** (Postgrex.Error) &quot;&quot;&quot; def delete_user!(%User{} = user) do Repo.delete!(user) end @doc &quot;&quot;&quot; Returns an `%Ecto.Changeset{}` for tracking user changes. ## Examples iex&gt; change_user(user) %Ecto.Changeset{source: %User{}} &quot;&quot;&quot; def change_user(%User{} = user) do User.changeset(user, %{}) end end Into this: defmodule MyApp.Accounts do use EctoResource alias MyApp.Repo alias MyApp.Accounts.User using_repo(Repo) do resource(User) end end"},{"ref":"readme.html#installation","title":"EctoResource - Installation","type":"extras","doc":"If available in Hex, the package can be installed by adding ecto_resource to your list of dependencies in mix.exs: def deps do [ {:ecto_resource, &quot;~&gt; 0.1.0&quot;} ] end"},{"ref":"readme.html#basic-usage","title":"EctoResource - Basic Usage","type":"extras","doc":"All examples are using a &quot;context&quot; module Accounts and a schema of User. This can be substituted for your Phoenix context, or any other module and schema. defmodule Accounts do use EctoResource using_repo(Repo) do resource(User) end end This will generate the functions: def create_user(attributes) do EctoResource.create(Repo, User, attributes) end def create_user!(attributes) do EctoResource.create!(Repo, User, attributes) end def all_users(options \\\\ []) do EctoResource.all(Repo, User, options) end def get_user(id, options \\\\ []) do EctoResource.get(Repo, User, id, options) end def get_user!(id, options \\\\ []) do EctoResource.get!(Repo, User, id, options) end def change_user(attributes) do EctoResource.change(User, attributes) end def update_user(%User{id: 1}, attributes) do EctoResource.update(Repo, User, struct, attributes) end def update_user!(%User{id: 1}, attributes) do EctoResource.update!(Repo, User, struct, attributes) end def delete_user(struct) do EctoResource.delete(Repo, struct) end def delete_user!(struct) do EctoResource.delete!(Repo, struct) end There are also introspection functions to understand what is generated by the macro Accounts.__resource__(:resources) == [ {Repo, User, [ &quot;all_users/1&quot;, &quot;change_user/1&quot;, &quot;create_user/1&quot;, &quot;create_user!/1&quot;, &quot;delete_user/1&quot;, &quot;delete_user!/1&quot;, &quot;get_user/2&quot;, &quot;get_user!/2&quot;, &quot;update_user/2&quot;, &quot;update_user!/2&quot; ]} ]"},{"ref":"readme.html#advanced-usage","title":"EctoResource - Advanced usage","type":"extras","doc":"More granular control is available through options"},{"ref":"readme.html#read","title":"EctoResource - :read","type":"extras","doc":"defmodule Accounts do use EctoResource using_repo(Repo) do resource(User, :read) end end This will generate the functions: def all_users(options \\\\ []) do EctoResource.all(Repo, User, options) end def get_user(id, options \\\\ []) do EctoResource.get(Repo, User, id, options) end def get_user!(id, options \\\\ []) do EctoResource.get!(Repo, User, id, options) end"},{"ref":"readme.html#read_write","title":"EctoResource - :read_write","type":"extras","doc":"defmodule Accounts do use EctoResource using_repo(Repo) do resource(User, :read_write) end end This will generate the functions: def all_users(options \\\\ []) do EctoResource.all(Repo, User, options) end def get_user(id, options \\\\ []) do EctoResource.get(Repo, User, id, options) end def get_user!(id, options \\\\ []) do EctoResource.get!(Repo, User, id, options) end def create_user(attributes) do EctoResource.create(Repo, User, attributes) end def create_user!(attributes) do EctoResource.create!(Repo, User, attributes) end def change_user(attributes) do EctoResource.change(User, attributes) end def update_user(%User{id: 1}, attributes) do EctoResource.update(Repo, User, struct, attributes) end def update_user!(%User{id: 1}, attributes) do EctoResource.update!(Repo, User, struct, attributes) end"},{"ref":"readme.html#only","title":"EctoResource - :only","type":"extras","doc":"defmodule Accounts do use EctoResource using_repo(Repo) do resource(User, only: [:change, :create!]) end This will generate the functions: def change_user(attributes) do EctoResource.change(User, attributes) end def create_user!(attributes) do EctoResource.change!(User, attributes) end"},{"ref":"readme.html#except","title":"EctoResource - :except","type":"extras","doc":"defmodule Accounts do use EctoResource using_repo(Repo) do resource(User, except: [:change, :update, :update!, :create!, :all, :get, :get!, :delete]) end This will generate the functions: def create_user(attributes) do EctoResource.create(Repo, User, attributes) end def delete_user!(struct_or_changeset) do EctoResource.delete!(Repo, struct_or_changeset) end Documentation can be generated with ExDoc and published on HexDocs. Once published, the docs can be found at https://hexdocs.pm/ecto_resource."}]